@@ -2,6 +2,7 @@ class Movement:
 
 	blocks = []
 	progressions = []
+	instruments = []
 	b_counter = 0
 	p_counter = 0
 
@@ -33,6 +34,9 @@ class Movement:
 	def set_default_key(self, key):
 		self.default_key = key
 	
+	def get_instruments(self):
+		return self.instruments
+
 	def get_next_block(self):
 		"""Prepares and returns the next block in the movement.\
 Returns None if there is no next block."""
