@@ -24,7 +24,7 @@ class OptionClass:
 	movement = "Movement"
 	width=400
 	height=400
-	frontend="DefaultVisualization"
+	frontend="blocks"
 	ensemble=None
 	no_fluidsynth=False
 	verbose=True
@@ -434,8 +434,11 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.ui.resolution.addItem(str(x))
 		for x in diatonic.basic_keys:
 			self.ui.key.addItem(x)
-		for x in ['default', 'alsa', 'oss', 'jack', 'portaudio', 'coreaudio', 'sndmgr', 'Direct Sound']:
+		for x in ['default', 'alsa', 'oss', 'jack', 'portaudio', 'coreaudio', 
+				'sndmgr', 'Direct Sound']:
 			self.ui.driver.addItem(x)
+		for x in ['', 'cli', 'lines', 'blocks', 'mixed']:
+			self.ui.visualization.addItem(x)
 				
 
 	def connect_widgets(self):
@@ -676,6 +679,11 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			i = combo_index_by_text(self.ui.driver, o.driver)
 		self.ui.driver.setCurrentIndex(i)
 
+		i = 0
+		if hasattr(o, 'visualization'):
+			i = combo_index_by_text(self.ui.visualization, o.visualization)
+		self.ui.visualization.setCurrentIndex(i)
+
 
 		# CheckBoxes
 		self.ui.swing.setChecked(bool(o.swing))
@@ -713,8 +721,11 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		o.resolution = int(str(self.ui.resolution.currentText()))
 		o.key = str(self.ui.key.currentText())
 		o.driver = str(self.ui.driver.currentText())
+		o.frontend = str(self.ui.visualization.currentText())
 		if o.driver == 'default':
 			o.driver = None
+		if o.frontend == '':
+			o.frontend = None
 
 		# SpinBoxes
 		o.bpm = int(self.ui.bpm.value())
